@@ -81,12 +81,12 @@ class PowerAsset(Asset):
         """
         metadata_filter = {"measurement_type": measurement_type, "timeseries_type": timeseries_type, **kwargs}
         metadata_filter = {k: v for k, v in metadata_filter.items() if v}
-        return self._cognite_client.time_series.list(asset_subtree_ids=[self.id], metadata=metadata_filter)
+        return self._cognite_client.time_series.list(asset_subtree_ids=[self.id], metadata=metadata_filter, limit=None)
 
     @staticmethod
     def _load_from_asset(asset, class_name, cognite_client):
         cls = _str_to_class(class_name) or PowerAsset
-        power_asset = cls(cognite_client=cognite_client, **asset.dump())
+        power_asset = cls._load(asset.dump(), cognite_client=cognite_client)
         if cls is not PowerAsset:
             assert power_asset.type in [
                 None,
@@ -187,7 +187,9 @@ class Analog(PowerAsset):
 
 
 class BusbarSection(PowerAsset):
-    pass
+    def substation(self) -> "Substation":
+        """Shortcut for finding the substation for a PowerTransformer"""
+        return assert_single_result(self.relationship_targets("Substation"))
 
 
 class CurrentLimit(PowerAsset):
@@ -330,6 +332,19 @@ class Substation(PowerAsset):
         return np.inf
 
 
+class PowerTransferCorridor(PowerAsset):
+    def synchronous_machines(self) -> "PowerAssetList":
+        """Shortcut for finding the associated SynchronousMachines for a PowerTransferCorridor.."""
+        return self.relationship_sources("SynchronousMachine")
+
+    def terminals(self, sequence_number: Optional[Union[int, Iterable]] = None) -> "PowerAssetList":
+        """Shortcut for finding the associated Terminals"""
+        filter = self._sequence_number_filter(sequence_number)
+        return self.synchronous_machines().relationship_sources(
+            "Terminal", relationship_type="connectsTo", x_filter=filter
+        )
+
+
 class PowerTransformerEnd(PowerAsset, LoadDurationMixin):
     def terminals(self, sequence_number: Optional[Union[int, Iterable]] = None) -> "PowerAssetList":
         """Shortcut for finding the associated Terminals"""
@@ -720,6 +735,7 @@ class PowerAssetList(AssetList):
             or self.has_type("WindGeneratingUnit")
             or self.has_type("ThermalGeneratingUnit")
             or self.has_type("HydroGeneratingUnit")
+            or self.has_type("BusbarSection")
         ):
             return self.relationship_targets("Substation")
         elif self.has_type("ACLineSegment"):
@@ -799,7 +815,7 @@ class PowerAssetList(AssetList):
         chunk_size = 100
         ids = [a.id for a in self.data]
         tasks = [
-            {"asset_subtree_ids": ids[i : i + self._retrieve_chunk_size], "metadata": metadata_filter}
+            {"asset_subtree_ids": ids[i : i + self._retrieve_chunk_size], "metadata": metadata_filter, "limit": None}
             for i in range(0, len(ids), chunk_size)
         ]
         res_list = execute_tasks_concurrently(self._cognite_client.time_series.list, tasks, max_workers=10)
@@ -866,8 +882,8 @@ class PowerAssetList(AssetList):
         index_granularity=0.1,
     ) -> "pd.DataFrame":
         """See ACLineSegment#load_duration_curve"""
-        if self.type not in ["ACLineSegment", "PowerTransformerEnd", "SynchronousMachine"]:
-            raise WrongPowerTypeError(f"Can't get connected current limits dataframe for a list of {self.type}")
+        if self.type not in ["ACLineSegment", "PowerTransformerEnd", "SynchronousMachine"]:  # , "PowerTransferCorridor"
+            raise WrongPowerTypeError(f"Can't get load duration curves dataframe for a list of {self.type}")
         if len(self.data) > 1000:
             raise ValueError("Too many line segments in this list to get load duration curves")
         res_list = execute_tasks_concurrently(
